# ChargeOverride

Charge associated with a rate plan. 

## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**name** | **str** | The name of a standalone charge.  **Note:** This field is available when the &lt;a href&#x3D;\&quot;https://knowledgecenter.zuora.com/Zuora_Billing/Manage_subscription_transactions/Orders/Standalone_Orders/AA_Overview_of_Standalone_Orders\&quot; target&#x3D;\&quot;_blank\&quot;&gt;Standalone Orders&lt;/a&gt; feature is enabled.  | [optional] 
**account_receivable_accounting_code** | **str** | The accountReceivableAccountingCode of a standalone charge.  **Note:** This field is available when the &lt;a href&#x3D;\&quot;https://knowledgecenter.zuora.com/Zuora_Billing/Manage_subscription_transactions/Orders/Standalone_Orders/AA_Overview_of_Standalone_Orders\&quot; target&#x3D;\&quot;_blank\&quot;&gt;Standalone Orders&lt;/a&gt;, &lt;a href&#x3D;\&quot;https://knowledgecenter.zuora.com/Zuora_Payments/Zuora_Finance\&quot; target&#x3D;\&quot;_blank\&quot;&gt;Zuora Finance&lt;/a&gt;, and &lt;a href&#x3D;\&quot;https://knowledgecenter.zuora.com/Zuora_Billing/Bill_your_customers/Adjust_invoice_amounts/Invoice_Settlement/Get_started_with_Invoice_Settlement/AA_Overview_of_Invoice_Settlement\&quot; target&#x3D;\&quot;_blank\&quot;&gt;Invoice Settlement&lt;/a&gt; features are enabled.  | [optional] 
**adjustment_liability_accounting_code** | **str** | The adjustmentLiabilityAccountingCode of a standalone charge.  **Note:** This field is available when the &lt;a href&#x3D;\&quot;https://knowledgecenter.zuora.com/Zuora_Billing/Manage_subscription_transactions/Orders/Standalone_Orders/AA_Overview_of_Standalone_Orders\&quot; target&#x3D;\&quot;_blank\&quot;&gt;Standalone Orders&lt;/a&gt; feature and the &lt;a href&#x3D;\&quot;https://knowledgecenter.zuora.com/Zuora_Revenue/Zuora_Billing_-_Revenue_Integration\&quot; target&#x3D;\&quot;_blank\&quot;&gt;Billing - Revenue Integration&lt;/a&gt; or &lt;a href&#x3D;\&quot;https://knowledgecenter.zuora.com/Zuora_Billing/Enable_Order_to_Revenue/Order_to_Revenue_introduction/AA_Overview_of_Order_to_Revenue\&quot; target&#x3D;\&quot;_blank\&quot;&gt;Order to Revenue&lt;/a&gt; feature are enabled.  | [optional] 
**adjustment_revenue_accounting_code** | **str** | The adjustmentRevenueAccountingCode of a standalone charge.  **Note:** This field is available when the &lt;a href&#x3D;\&quot;https://knowledgecenter.zuora.com/Zuora_Billing/Manage_subscription_transactions/Orders/Standalone_Orders/AA_Overview_of_Standalone_Orders\&quot; target&#x3D;\&quot;_blank\&quot;&gt;Standalone Orders&lt;/a&gt; feature and the &lt;a href&#x3D;\&quot;https://knowledgecenter.zuora.com/Zuora_Revenue/Zuora_Billing_-_Revenue_Integration\&quot; target&#x3D;\&quot;_blank\&quot;&gt;Billing - Revenue Integration&lt;/a&gt; or &lt;a href&#x3D;\&quot;https://knowledgecenter.zuora.com/Zuora_Billing/Enable_Order_to_Revenue/Order_to_Revenue_introduction/AA_Overview_of_Order_to_Revenue\&quot; target&#x3D;\&quot;_blank\&quot;&gt;Order to Revenue&lt;/a&gt; feature are enabled.  | [optional] 
**contract_asset_accounting_code** | **str** | The contractAssetAccountingCode of a standalone charge.  **Note:** This field is available when the &lt;a href&#x3D;\&quot;https://knowledgecenter.zuora.com/Zuora_Billing/Manage_subscription_transactions/Orders/Standalone_Orders/AA_Overview_of_Standalone_Orders\&quot; target&#x3D;\&quot;_blank\&quot;&gt;Standalone Orders&lt;/a&gt; feature and the &lt;a href&#x3D;\&quot;https://knowledgecenter.zuora.com/Zuora_Revenue/Zuora_Billing_-_Revenue_Integration\&quot; target&#x3D;\&quot;_blank\&quot;&gt;Billing - Revenue Integration&lt;/a&gt; or &lt;a href&#x3D;\&quot;https://knowledgecenter.zuora.com/Zuora_Billing/Enable_Order_to_Revenue/Order_to_Revenue_introduction/AA_Overview_of_Order_to_Revenue\&quot; target&#x3D;\&quot;_blank\&quot;&gt;Order to Revenue&lt;/a&gt; feature are enabled.  | [optional] 
**contract_liability_accounting_code** | **str** | The contractLiabilityAccountingCode of a standalone charge.  **Note:** This field is available when the &lt;a href&#x3D;\&quot;https://knowledgecenter.zuora.com/Zuora_Billing/Manage_subscription_transactions/Orders/Standalone_Orders/AA_Overview_of_Standalone_Orders\&quot; target&#x3D;\&quot;_blank\&quot;&gt;Standalone Orders&lt;/a&gt; feature and the &lt;a href&#x3D;\&quot;https://knowledgecenter.zuora.com/Zuora_Revenue/Zuora_Billing_-_Revenue_Integration\&quot; target&#x3D;\&quot;_blank\&quot;&gt;Billing - Revenue Integration&lt;/a&gt; or &lt;a href&#x3D;\&quot;https://knowledgecenter.zuora.com/Zuora_Billing/Enable_Order_to_Revenue/Order_to_Revenue_introduction/AA_Overview_of_Order_to_Revenue\&quot; target&#x3D;\&quot;_blank\&quot;&gt;Order to Revenue&lt;/a&gt; feature are enabled.  | [optional] 
**contract_recognized_revenue_accounting_code** | **str** | The contractRecognizedRevenueAccountingCode of a standalone charge.  **Note:** This field is available when the &lt;a href&#x3D;\&quot;https://knowledgecenter.zuora.com/Zuora_Billing/Manage_subscription_transactions/Orders/Standalone_Orders/AA_Overview_of_Standalone_Orders\&quot; target&#x3D;\&quot;_blank\&quot;&gt;Standalone Orders&lt;/a&gt; feature and the &lt;a href&#x3D;\&quot;https://knowledgecenter.zuora.com/Zuora_Revenue/Zuora_Billing_-_Revenue_Integration\&quot; target&#x3D;\&quot;_blank\&quot;&gt;Billing - Revenue Integration&lt;/a&gt; or &lt;a href&#x3D;\&quot;https://knowledgecenter.zuora.com/Zuora_Billing/Enable_Order_to_Revenue/Order_to_Revenue_introduction/AA_Overview_of_Order_to_Revenue\&quot; target&#x3D;\&quot;_blank\&quot;&gt;Order to Revenue&lt;/a&gt; feature are enabled.  | [optional] 
**deferred_revenue_accounting_code** | **str** | The deferredRevenueAccountingCode of a standalone charge.  **Note:** This field is available when the &lt;a href&#x3D;\&quot;https://knowledgecenter.zuora.com/Zuora_Billing/Manage_subscription_transactions/Orders/Standalone_Orders/AA_Overview_of_Standalone_Orders\&quot; target&#x3D;\&quot;_blank\&quot;&gt;Standalone Orders&lt;/a&gt; and &lt;a href&#x3D;\&quot;https://knowledgecenter.zuora.com/Zuora_Payments/Zuora_Finance\&quot; target&#x3D;\&quot;_blank\&quot;&gt;Zuora Finance&lt;/a&gt; features are enabled.  | [optional] 
**recognized_revenue_accounting_code** | **str** | The recognizedRevenueAccountingCode of a standalone charge.  **Note:** This field is available when the &lt;a href&#x3D;\&quot;https://knowledgecenter.zuora.com/Zuora_Billing/Manage_subscription_transactions/Orders/Standalone_Orders/AA_Overview_of_Standalone_Orders\&quot; target&#x3D;\&quot;_blank\&quot;&gt;Standalone Orders&lt;/a&gt; and &lt;a href&#x3D;\&quot;https://knowledgecenter.zuora.com/Zuora_Payments/Zuora_Finance\&quot; target&#x3D;\&quot;_blank\&quot;&gt;Zuora Finance&lt;/a&gt; features are enabled.  | [optional] 
**un_billed_receivables_accounting_code** | **str** | The unBilledReceivablesAccountingCode of a standalone charge.  **Note:** This field is available when the &lt;a href&#x3D;\&quot;https://knowledgecenter.zuora.com/Zuora_Billing/Manage_subscription_transactions/Orders/Standalone_Orders/AA_Overview_of_Standalone_Orders\&quot; target&#x3D;\&quot;_blank\&quot;&gt;Standalone Orders&lt;/a&gt; feature and the &lt;a href&#x3D;\&quot;https://knowledgecenter.zuora.com/Zuora_Revenue/Zuora_Billing_-_Revenue_Integration\&quot; target&#x3D;\&quot;_blank\&quot;&gt;Billing - Revenue Integration&lt;/a&gt; or &lt;a href&#x3D;\&quot;https://knowledgecenter.zuora.com/Zuora_Billing/Enable_Order_to_Revenue/Order_to_Revenue_introduction/AA_Overview_of_Order_to_Revenue\&quot; target&#x3D;\&quot;_blank\&quot;&gt;Order to Revenue&lt;/a&gt; feature are enabled.  | [optional] 
**product_category** | **str** | The productCategory of a standalone charge.  **Note:** This field is available when the &lt;a href&#x3D;\&quot;https://knowledgecenter.zuora.com/Zuora_Billing/Manage_subscription_transactions/Orders/Standalone_Orders/AA_Overview_of_Standalone_Orders\&quot; target&#x3D;\&quot;_blank\&quot;&gt;Standalone Orders&lt;/a&gt; feature is enabled.  | [optional] 
**product_class** | **str** | The productClass of a standalone charge.  **Note:** This field is available when the &lt;a href&#x3D;\&quot;https://knowledgecenter.zuora.com/Zuora_Billing/Manage_subscription_transactions/Orders/Standalone_Orders/AA_Overview_of_Standalone_Orders\&quot; target&#x3D;\&quot;_blank\&quot;&gt;Standalone Orders&lt;/a&gt; feature is enabled.  | [optional] 
**product_family** | **str** | The productFamily of a standalone charge.  **Note:** This field is available when the &lt;a href&#x3D;\&quot;https://knowledgecenter.zuora.com/Zuora_Billing/Manage_subscription_transactions/Orders/Standalone_Orders/AA_Overview_of_Standalone_Orders\&quot; target&#x3D;\&quot;_blank\&quot;&gt;Standalone Orders&lt;/a&gt; feature is enabled.  | [optional] 
**product_line** | **str** | The productLine of a standalone charge.  **Note:** This field is available when the &lt;a href&#x3D;\&quot;https://knowledgecenter.zuora.com/Zuora_Billing/Manage_subscription_transactions/Orders/Standalone_Orders/AA_Overview_of_Standalone_Orders\&quot; target&#x3D;\&quot;_blank\&quot;&gt;Standalone Orders&lt;/a&gt; feature is enabled.  | [optional] 
**charge_model** | [**ChargeModel**](ChargeModel.md) |  | [optional] 
**charge_type** | [**ChargeType**](ChargeType.md) |  | [optional] 
**tax_code** | **str** | The taxCode of a charge. This field is available when the field &#39;taxable&#39; is set to true.  | [optional] 
**tax_mode** | [**TaxMode**](TaxMode.md) |  | [optional] 
**taxable** | **bool** | The flag to indicate whether the charge is taxable. If this field is set to true, both the fields &#x60;taxCode&#x60; and &#x60;taxMode&#x60; are required.  | [optional] 
**revenue_recognition_timing** | **str** | This field is used to dictate the type of revenue recognition timing.  | [optional] 
**revenue_amortization_method** | **str** | This field is used to dictate the type of revenue amortization method.  | [optional] 
**is_charge_level_min_commit** | **bool** | The flag to indicate whether the charge is charge level min commit.  **Note:** This field is available when the &lt;a href&#x3D;\&quot;https://knowledgecenter.zuora.com/Zuora_Billing/Manage_subscription_transactions/Orders/Standalone_Orders/AA_Overview_of_Standalone_Orders\&quot; target&#x3D;\&quot;_blank\&quot;&gt;Standalone Orders&lt;/a&gt; feature is enabled.  | [optional] 
**commitment_type** | [**CommitmentType**](CommitmentType.md) |  | [optional] 
**prepaid_operation_type** | [**PrepaidOperationType**](PrepaidOperationType.md) |  | [optional] 
**is_committed** | **bool** | The flag to indicate whether the charge is committed.   | [optional] 
**charge_function** | [**ChargeFunction**](ChargeFunction.md) |  | [optional] 
**prepaid_uom** | **str** | The prepaid unit of measure of the charge.   | [optional] 
**drawdown_uom** | **str** | The drawdown unit of measure of the charge.   | [optional] 
**prepaid_total_quantity** | **float** | The prepaid total quantity of the charge.   | [optional] 
**is_prepaid** | **bool** | The flag to indicate whether the charge is prepaid.   | [optional] 
**credit_option** | [**PrepaidDrawdownCreditOption**](PrepaidDrawdownCreditOption.md) |  | [optional] 
**billing** | [**ChargeOverrideBilling**](ChargeOverrideBilling.md) |  | [optional] 
**charge_number** | **str** | Charge number of the charge. For example, C-00000307.  If you do not set this field, Zuora will generate the charge number.  | [optional] 
**custom_fields** | **Dict[str, object]** | Container for custom fields of a Rate Plan Charge object.  | [optional] 
**description** | **str** | Description of the charge.  | [optional] 
**drawdown_rate** | **float** | **Note**: This field is only available if you have the [Prepaid with Drawdown](https://knowledgecenter.zuora.com/Billing/Billing_and_Payments/J_Billing_Operations/Prepaid_with_Drawdown) feature enabled.  The [conversion rate](https://knowledgecenter.zuora.com/Billing/Billing_and_Payments/J_Billing_Operations/Prepaid_with_Drawdown/Create_drawdown_charge#UOM_Conversion) between Usage UOM and Drawdown UOM for a [drawdown charge](https://knowledgecenter.zuora.com/Billing/Billing_and_Payments/J_Billing_Operations/Prepaid_with_Drawdown/Create_drawdown_charge). Must be a positive number (&gt;0).  | [optional] 
**end_date** | [**EndConditions**](EndConditions.md) |  | [optional] 
**exclude_item_billing_from_revenue_accounting** | **bool** | The flag to exclude rate plan charge related invoice items, invoice item adjustments, credit memo items, and debit memo items from revenue accounting.   **Note**: This field is only available if you have the [Zuora Billing - Revenue Integration](https://knowledgecenter.zuora.com/Zuora_Revenue/Zuora_Billing_-_Revenue_Integration) feature enabled.   | [optional] 
**exclude_item_booking_from_revenue_accounting** | **bool** | The flag to exclude rate plan charges from revenue accounting.   **Note**: This field is only available if you have the [Zuora Billing - Revenue Integration](https://knowledgecenter.zuora.com/Zuora_Revenue/Zuora_Billing_-_Revenue_Integration) feature enabled.   | [optional] 
**is_allocation_eligible** | **bool** | This field is used to identify if the charge segment is allocation eligible in revenue recognition.  **Note**: This feature is in the **Early Adopter** phase. If you want to use the feature, submit a request at &lt;a href&#x3D;\&quot;https://support.zuora.com/\&quot; target&#x3D;\&quot;_blank\&quot;&gt;Zuora Global Support&lt;/a&gt;, and we will evaluate whether the feature is suitable for your use cases.  | [optional] 
**is_rollover** | **bool** | **Note**: This field is only available if you have the [Prepaid with Drawdown](https://knowledgecenter.zuora.com/Billing/Billing_and_Payments/J_Billing_Operations/Prepaid_with_Drawdown) feature enabled.  To use this field, you must set the &#x60;X-Zuora-WSDL-Version&#x60; request header to 114 or higher. Otherwise, an error occurs.  The value is either \&quot;True\&quot; or \&quot;False\&quot;. It determines whether the rollover fields are needed.  | [optional] 
**is_unbilled** | **bool** | This field is used to dictate how to perform the accounting during revenue recognition.  **Note**: This feature is in the **Early Adopter** phase. If you want to use the feature, submit a request at &lt;a href&#x3D;\&quot;https://support.zuora.com/\&quot; target&#x3D;\&quot;_blank\&quot;&gt;Zuora Global Support&lt;/a&gt;, and we will evaluate whether the feature is suitable for your use cases.  | [optional] 
**prepaid_quantity** | **float** | **Note**: This field is only available if you have the [Prepaid with Drawdown](https://knowledgecenter.zuora.com/Billing/Billing_and_Payments/J_Billing_Operations/Prepaid_with_Drawdown) feature enabled.  The number of units included in a [prepayment charge](https://knowledgecenter.zuora.com/Billing/Billing_and_Payments/J_Billing_Operations/Prepaid_with_Drawdown/Create_prepayment_charge). Must be a positive number (&gt;0).  | [optional] 
**pricing** | [**ChargeOverridePricing**](ChargeOverridePricing.md) |  | [optional] 
**product_rate_plan_charge_number** | **str** | Number of a product rate-plan charge for this subscription.  | [optional] 
**product_rate_plan_charge_id** | **str** | Internal identifier of the product rate plan charge that the charge is based on.  | 
**proration_option** | [**ProrationOption**](ProrationOption.md) |  | [optional] 
**rating_properties_override** | [**RatingPropertiesOverride**](RatingPropertiesOverride.md) |  | [optional] 
**rev_rec_code** | **str** | Revenue Recognition Code  | [optional] 
**rev_rec_trigger_condition** | [**RevRecTriggerCondition**](RevRecTriggerCondition.md) |  | [optional] 
**revenue_recognition_rule_name** | **str** | Specifies the revenue recognition rule, such as &#x60;Recognize upon invoicing&#x60; or &#x60;Recognize daily over time&#x60;.  | [optional] 
**rollover_apply** | [**RolloverApply**](RolloverApply.md) |  | [optional] 
**rollover_periods** | **float** | **Note**: This field is only available if you have the [Prepaid with Drawdown](https://knowledgecenter.zuora.com/Billing/Billing_and_Payments/J_Billing_Operations/Prepaid_with_Drawdown) feature enabled.  To use this field, you must set the &#x60;X-Zuora-WSDL-Version&#x60; request header to 114 or higher. Otherwise, an error occurs.  This field defines the number of rollover periods, it is restricted to 3.  | [optional] 
**estimated_start_date** | **date** | Estimated start date of the charge. This field is only available when the charge is changed through the related order actions. **Note:** This field is available when the &lt;a href&#x3D;\&quot;https://knowledgecenter.zuora.com/Zuora_Billing/Manage_subscription_transactions/Orders/\&quot; target&#x3D;\&quot;_blank\&quot;&gt;Pending Charge Flexibility&lt;/a&gt; feature is enabled.  | [optional] 
**start_date** | [**TriggerParams**](TriggerParams.md) |  | [optional] 
**unique_token** | **str** | Unique identifier for the charge. This identifier enables you to refer to the charge before the charge has an internal identifier in Zuora.  For instance, suppose that you want to use a single order to add a product to a subscription and later update the same product. When you add the product, you can set a unique identifier for the charge. Then when you update the product, you can use the same unique identifier to specify which charge to modify.  | [optional] 
**upsell_origin_charge_number** | **str** | **Note**: The Quantity Upsell feature is in Limited Availability. If you wish to have access to the feature, submit a request at [Zuora Global Support](https://support.zuora.com).  The identifier of the original upselling charge associated with the current charge.  | [optional] 
**validity_period_type** | [**ValidityPeriodType**](ValidityPeriodType.md) |  | [optional] 
**commitment_level** | [**CommitmentLevel**](CommitmentLevel.md) |  | [optional] 

## Example

```python
from zuora_sdk.models.charge_override import ChargeOverride

# TODO update the JSON string below
json = "{}"
# create an instance of ChargeOverride from a JSON string
charge_override_instance = ChargeOverride.from_json(json)
# print the JSON string representation of the object
print(ChargeOverride.to_json())

# convert the object into a dict
charge_override_dict = charge_override_instance.to_dict()
# create an instance of ChargeOverride from a dict
charge_override_from_dict = ChargeOverride.from_dict(charge_override_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


